"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../src");
const shippingData = [
    [23, 0, 0, 19],
    {
        AS: [undefined, { IR: [[], {}], KP: [[], {}], SY: [[], {}] }],
        EU: [undefined, { BY: [[], {}], RU: [[], {}] }],
        NA: [
            [31, 0, 0, 29],
            { CU: [[], {}], US: [[41, 0, 0, 37], { CA: [[53, 0, 0, 51]] }] },
        ],
        SA: [undefined, { VE: [[], {}] }],
    },
];
describe('Pricing Calculator', () => {
    it('should calculate the pricing of an example product with Customizations and shipping Correctly using main unit by default', () => {
        const exampleProduct = {
            currency: { decimals: 2, symbol: 'usd' },
            price: 799,
            rewardShare: 19.5,
            startAmountPercent: 22.5,
            shipping: shippingData,
        };
        const exampleTraitCombination = { price: 1300 };
        const usedRewards = [{ worth: 300 }];
        const pricingInformation = (0, src_1.calculatePricingInformation)({
            product: exampleProduct,
            combination: exampleTraitCombination,
            usedRewards,
            stateCode: 'CA',
            countryCode: 'US',
        });
        expect(pricingInformation.reserve.base + pricingInformation.claim.base).toBe(pricingInformation.total.base);
        expect(pricingInformation.startAmountPercent).toBe(22.5);
        expect(pricingInformation.reserve.base).toBe(1.8);
        expect(pricingInformation.claim.base).toBe(6.19);
        expect(pricingInformation.total.base).toBe(7.99);
        // reserve.base + traitCost + shippingCost + taxCost - usedRewardsTotal = reserve.total
        // 180 + 1300 + 5100 + 3815 - 300 = 10095
        expect(pricingInformation.reserve.total).toBe(100.95);
        expect(pricingInformation.reserve.taxCost).toBe(38.15);
        expect(pricingInformation.reserve.gainedRewardsAmount).toBe(0.35);
        expect(pricingInformation.claim.gainedRewardsAmount).toBe(1.21);
        expect(pricingInformation.total.gainedRewardsAmount).toBe(1.56);
        // total.base + traitCost + shippingCost + taxCost - usedRewardsTotal = total.total
        // 799 + 1300 + 5100 + 3815 - 300 = 10714
        expect(pricingInformation.total.total).toBe(107.14);
    });
    it('should calculate the pricing of an example product with customizations and shipping correctly with smallest unit if requested', () => {
        const exampleProduct = {
            currency: { decimals: 2, symbol: 'usd' },
            price: 799,
            rewardShare: 19.5,
            startAmountPercent: 22.5,
            shipping: shippingData,
        };
        const exampleTraitCombination = { price: 1300 };
        const usedRewards = [{ worth: 300 }];
        const pricingInformation = (0, src_1.calculatePricingInformation)({
            product: exampleProduct,
            combination: exampleTraitCombination,
            usedRewards,
            stateCode: 'CA',
            countryCode: 'US',
        }, { returnSmallestUnit: true });
        expect(pricingInformation.reserve.base + pricingInformation.claim.base).toBe(pricingInformation.total.base);
        expect(pricingInformation.startAmountPercent).toBe(22.5);
        expect(pricingInformation.reserve.base).toBe(180);
        expect(pricingInformation.claim.base).toBe(619);
        expect(pricingInformation.total.base).toBe(799);
        // reserve.base + traitCost + shippingCost + taxCost - usedRewardsTotal = reserve.total
        // 180 + 1300 + 5100 + 3815 - 300 = 10095
        expect(pricingInformation.reserve.total).toBe(10095);
        expect(pricingInformation.reserve.taxCost).toBe(3815);
        expect(pricingInformation.reserve.gainedRewardsAmount).toBe(35);
        expect(pricingInformation.claim.gainedRewardsAmount).toBe(121);
        expect(pricingInformation.total.gainedRewardsAmount).toBe(156);
        // total.base + traitCost + shippingCost + taxCost - usedRewardsTotal = total.total
        // 799 + 1300 + 5100 + 3815 - 300 = 10714
        expect(pricingInformation.total.total).toBe(10714);
    });
});
