"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../src/utils");
describe('Utils', () => {
    describe('priceFormatter', () => {
        const testCases = [
            {
                description: 'format price with decimals',
                priceSmallestUnit: 799,
                priceMainUnit: 7.99,
                currency: { symbol: '$', decimals: 2 },
                expected: '$ 7.99',
            },
            {
                description: 'format integer price by removing trailing zeros',
                priceSmallestUnit: 800,
                priceMainUnit: 8.0,
                currency: { symbol: '$', decimals: 2 },
                expected: '$ 8',
            },
            {
                description: 'format price with different currency symbol',
                priceSmallestUnit: 799,
                priceMainUnit: 7.99,
                currency: { symbol: '€', decimals: 2 },
                expected: '€ 7.99',
            },
            {
                description: 'format price with different decimals',
                priceSmallestUnit: 12345,
                priceMainUnit: 12.345,
                currency: { symbol: '$', decimals: 3 },
                expected: '$ 12.345',
            },
            {
                description: 'format price with empty string as symbol',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                currency: { symbol: '', decimals: 2 },
                expected: ' 12.34',
            },
            {
                description: 'format price with empty string as symbol and a negative',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                currency: { symbol: '', decimals: 2 },
                negative: true,
                expected: '- 12.34',
            },
            // Edge cases
            {
                description: 'format zero price',
                priceSmallestUnit: 0,
                priceMainUnit: 0.0,
                currency: { symbol: '$', decimals: 2 },
                expected: '$ 0',
            },
            {
                description: 'format price with no decimals',
                priceSmallestUnit: 1234,
                priceMainUnit: 1234,
                currency: { symbol: '$', decimals: 0 },
                expected: '$ 1,234',
            },
            {
                description: 'format price with a negative',
                priceSmallestUnit: 1234,
                priceMainUnit: 12.34,
                currency: { symbol: '$', decimals: 2 },
                negative: true,
                expected: '-$ 12.34',
            },
        ];
        describe('when price is in smallest unit', () => {
            testCases.forEach(({ description, priceSmallestUnit, currency, negative, expected }) => {
                it(`should ${description} from smallest unit`, () => {
                    const formattedPrice = (0, utils_1.priceFormatter)({
                        price: priceSmallestUnit,
                        currency,
                        fromSmallestUnit: true,
                        negative,
                    });
                    expect(formattedPrice).toBe(expected);
                });
            });
        });
        describe('when price is in main unit', () => {
            testCases.forEach(({ description, priceMainUnit, currency, negative, expected }) => {
                it(`should ${description} from main unit`, () => {
                    const formattedPrice = (0, utils_1.priceFormatter)({
                        price: priceMainUnit,
                        currency,
                        negative,
                    });
                    expect(formattedPrice).toBe(expected);
                });
            });
        });
    });
});
